import { world, system, ItemComponentTypes, ItemStack } from "@minecraft/server"

world.afterEvents.playerBreakBlock.subscribe((event) => {
    const source = event.player;
    const itemStack = event.itemStackAfterBreak;

    if (itemStack && itemStack.typeId === "bey:flame_pickaxe") {
        const durability = itemStack.getComponent(ItemComponentTypes.Durability);

        if (durability.damage === durability.maxDurability) {
            source.playSound('random.break');
            source.getComponent('equippable').setEquipment('Mainhand', undefined);
        } else {
            durability.damage++;
            source.getComponent('equippable').setEquipment('Mainhand', itemStack);
        }

        // Add a delay of 1 ticks before running the command
        system.runTimeout(() => {
            source.runCommandAsync("function pickaxe_melter");
        }, 1);
    }
});


world.afterEvents.playerBreakBlock.subscribe((event) => {
    const source = event.player;
    const itemStack = event.itemStackAfterBreak;

    if (itemStack && itemStack.typeId == "bey:flame_axe") {
        const durability = itemStack.getComponent(ItemComponentTypes.Durability);
        if (durability.damage === durability.maxDurability) {
            source.playSound('random.break');
            source.getComponent('equippable').setEquipment('Mainhand', undefined);
        }
        else {
            durability.damage++;
            source.getComponent('equippable').setEquipment('Mainhand', itemStack);
        }

        system.runTimeout(() => {
            source.runCommandAsync("function pickaxe_melter");
        }, 1);
    }
});

world.afterEvents.entityHitEntity.subscribe((event => {
    let player = event.damagingEntity;
    if (player) {
        function getMainHand(player) {
            const equippable = player.getComponent('equippable');
            return equippable?.getEquipment('Mainhand');
        }
        if (getMainHand(player)?.typeId === 'bey:flame_blade') {
            event.hitEntity?.runCommand("/scoreboard players add @s flameConnect 1")
        }
    }
}));

world.afterEvents.entityHurt.subscribe((event) => {
    const flameObj = world.scoreboard.getObjective("overallFlemArmor");
    const player = event.hurtEntity;

    if (flameObj && player?.typeId === "minecraft:player") {
        const flameScore = flameObj.getScore(player);
        const damage = flameScore >= 1 && flameScore <= 4 ? 1 + flameScore : 0;

        if (damage > 0) {
            player.addTag("isSource");

            player.dimension.getEntities({
                location: player.location,
                maxDistance: 3
            }).forEach(entity => {
                if (!entity.hasTag("isSource")) {
                    entity.applyDamage(damage);
                }
            });
            let playerLoc = player.location
            world.getDimension('overworld').spawnParticle('bey:flame_circle', playerLoc)
            player.removeTag("isSource");
        }
    }
});
